==> zio-aws-databasemigration_2.12-5.19.7.3-sources.jar: zio/aws/databasemigration/model/package.scala <==
package zio.aws.databasemigration
import zio.aws.databasemigration.model.primitives.Integer
import zio.aws.databasemigration.model.primitives.TStamp.Type
import java.time.Instant
import zio.Chunk
import zio.prelude.Subtype
package object model {
  import scala.jdk.CollectionConverters._
  object primitives {
    type BooleanOptional = Boolean
    object CertificateWallet extends Subtype[Chunk[Byte]]
    type CertificateWallet =
      zio.aws.databasemigration.model.primitives.CertificateWallet.Type
    type DoubleOptional = Double
    type Integer = Int
    type IntegerOptional = Int
    type LongOptional = Long
    object SecretString extends Subtype[String]
    type SecretString =
      zio.aws.databasemigration.model.primitives.SecretString.Type
    object TStamp extends Subtype[Instant]
    type TStamp = zio.aws.databasemigration.model.primitives.TStamp.Type
  }
  type AccountQuotaList = List[zio.aws.databasemigration.model.AccountQuota]
  type ArnList = List[String]
  type AvailabilityZonesList = List[String]
  type CertificateList = List[zio.aws.databasemigration.model.Certificate]
  type CollectorResponses =
    List[zio.aws.databasemigration.model.CollectorResponse]
  type CollectorsList =
    List[zio.aws.databasemigration.model.CollectorShortInfoResponse]
  type ConnectionList = List[zio.aws.databasemigration.model.Connection]
  type DatabaseList = List[zio.aws.databasemigration.model.DatabaseResponse]
  type EndpointList = List[zio.aws.databasemigration.model.Endpoint]
  type EndpointSettingEnumValues = List[String]
  type EndpointSettingsList =
    List[zio.aws.databasemigration.model.EndpointSetting]
  type EventCategoriesList = List[String]
  type EventCategoryGroupList =
    List[zio.aws.databasemigration.model.EventCategoryGroup]
  type EventList = List[zio.aws.databasemigration.model.Event]
  type EventSubscriptionsList =
    List[zio.aws.databasemigration.model.EventSubscription]
  type ExcludeTestList = List[String]
  type FilterList = List[zio.aws.databasemigration.model.Filter]
  type FilterValueList = List[String]
  type FleetAdvisorLsaAnalysisResponseList =
    List[zio.aws.databasemigration.model.FleetAdvisorLsaAnalysisResponse]
  type FleetAdvisorSchemaList =
    List[zio.aws.databasemigration.model.SchemaResponse]
  type FleetAdvisorSchemaObjectList =
    List[zio.aws.databasemigration.model.FleetAdvisorSchemaObjectResponse]
  type IncludeTestList = List[String]
  type IndividualAssessmentNameList = List[String]
  type IntegerList = List[Integer]
  type KeyList = List[String]
  type OrderableReplicationInstanceList =
    List[zio.aws.databasemigration.model.OrderableReplicationInstance]
  type PendingMaintenanceActionDetails =
    List[zio.aws.databasemigration.model.PendingMaintenanceAction]
  type PendingMaintenanceActions =
    List[zio.aws.databasemigration.model.ResourcePendingMaintenanceActions]
  type ReplicationInstanceIpv6AddressList = List[String]
  type ReplicationInstanceList =
    List[zio.aws.databasemigration.model.ReplicationInstance]
  type ReplicationInstancePrivateIpAddressList = List[String]
  type ReplicationInstancePublicIpAddressList = List[String]
  type ReplicationInstanceTaskLogsList =
    List[zio.aws.databasemigration.model.ReplicationInstanceTaskLog]
  type ReplicationSubnetGroups =
    List[zio.aws.databasemigration.model.ReplicationSubnetGroup]
  type ReplicationTaskAssessmentResultList =
    List[zio.aws.databasemigration.model.ReplicationTaskAssessmentResult]
  type ReplicationTaskAssessmentRunList =
    List[zio.aws.databasemigration.model.ReplicationTaskAssessmentRun]
  type ReplicationTaskIndividualAssessmentList =
    List[zio.aws.databasemigration.model.ReplicationTaskIndividualAssessment]
  type ReplicationTaskList =
    List[zio.aws.databasemigration.model.ReplicationTask]
  type SchemaList = List[String]
  type SourceIdsList = List[String]
  type StringList = List[String]
  type SubnetIdentifierList = List[String]
  type SubnetList = List[zio.aws.databasemigration.model.Subnet]
  type SupportedEndpointTypeList =
    List[zio.aws.databasemigration.model.SupportedEndpointType]
  type TableListToReload = List[zio.aws.databasemigration.model.TableToReload]
  type TableStatisticsList =
    List[zio.aws.databasemigration.model.TableStatistics]
  type TagList = List[zio.aws.databasemigration.model.Tag]
  type VpcSecurityGroupIdList = List[String]
  type VpcSecurityGroupMembershipList =
    List[zio.aws.databasemigration.model.VpcSecurityGroupMembership]
}

==> zio-aws-databasemigration_2.13-5.17.112.1-sources.jar: zio/aws/databasemigration/model/package.scala <==
package zio.aws.databasemigration
import zio.aws.databasemigration.model.primitives.Integer
import zio.aws.databasemigration.model.primitives.TStamp.Type
import java.time.Instant
import zio.Chunk
import zio.prelude.Subtype
package object model {
  import scala.jdk.CollectionConverters._
  object primitives {
    object BooleanOptional extends Subtype[Boolean]
    type BooleanOptional =
      zio.aws.databasemigration.model.primitives.BooleanOptional.Type
    object CertificateWallet extends Subtype[Chunk[Byte]]
    type CertificateWallet =
      zio.aws.databasemigration.model.primitives.CertificateWallet.Type
    object Integer extends Subtype[Int]
    type Integer = zio.aws.databasemigration.model.primitives.Integer.Type
    object IntegerOptional extends Subtype[Int]
    type IntegerOptional =
      zio.aws.databasemigration.model.primitives.IntegerOptional.Type
    object SecretString extends Subtype[String]
    type SecretString =
      zio.aws.databasemigration.model.primitives.SecretString.Type
    object TStamp extends Subtype[Instant]
    type TStamp = zio.aws.databasemigration.model.primitives.TStamp.Type
  }
  type AccountQuotaList = List[zio.aws.databasemigration.model.AccountQuota]
  type ArnList = List[String]
  type AvailabilityZonesList = List[String]
  type CertificateList = List[zio.aws.databasemigration.model.Certificate]
  type ConnectionList = List[zio.aws.databasemigration.model.Connection]
  type EndpointList = List[zio.aws.databasemigration.model.Endpoint]
  type EndpointSettingEnumValues = List[String]
  type EndpointSettingsList =
    List[zio.aws.databasemigration.model.EndpointSetting]
  type EventCategoriesList = List[String]
  type EventCategoryGroupList =
    List[zio.aws.databasemigration.model.EventCategoryGroup]
  type EventList = List[zio.aws.databasemigration.model.Event]
  type EventSubscriptionsList =
    List[zio.aws.databasemigration.model.EventSubscription]
  type ExcludeTestList = List[String]
  type FilterList = List[zio.aws.databasemigration.model.Filter]
  type FilterValueList = List[String]
  type IncludeTestList = List[String]
  type IndividualAssessmentNameList = List[String]
  type IntegerList = List[Integer]
  type KeyList = List[String]
  type OrderableReplicationInstanceList =
    List[zio.aws.databasemigration.model.OrderableReplicationInstance]
  type PendingMaintenanceActionDetails =
    List[zio.aws.databasemigration.model.PendingMaintenanceAction]
  type PendingMaintenanceActions =
    List[zio.aws.databasemigration.model.ResourcePendingMaintenanceActions]
  type ReplicationInstanceList =
    List[zio.aws.databasemigration.model.ReplicationInstance]
  type ReplicationInstancePrivateIpAddressList = List[String]
  type ReplicationInstancePublicIpAddressList = List[String]
  type ReplicationInstanceTaskLogsList =
    List[zio.aws.databasemigration.model.ReplicationInstanceTaskLog]
  type ReplicationSubnetGroups =
    List[zio.aws.databasemigration.model.ReplicationSubnetGroup]
  type ReplicationTaskAssessmentResultList =
    List[zio.aws.databasemigration.model.ReplicationTaskAssessmentResult]
  type ReplicationTaskAssessmentRunList =
    List[zio.aws.databasemigration.model.ReplicationTaskAssessmentRun]
  type ReplicationTaskIndividualAssessmentList =
    List[zio.aws.databasemigration.model.ReplicationTaskIndividualAssessment]
  type ReplicationTaskList =
    List[zio.aws.databasemigration.model.ReplicationTask]
  type SchemaList = List[String]
  type SourceIdsList = List[String]
  type SubnetIdentifierList = List[String]
  type SubnetList = List[zio.aws.databasemigration.model.Subnet]
  type SupportedEndpointTypeList =
    List[zio.aws.databasemigration.model.SupportedEndpointType]
  type TableListToReload = List[zio.aws.databasemigration.model.TableToReload]
  type TableStatisticsList =
    List[zio.aws.databasemigration.model.TableStatistics]
  type TagList = List[zio.aws.databasemigration.model.Tag]
  type VpcSecurityGroupIdList = List[String]
  type VpcSecurityGroupMembershipList =
    List[zio.aws.databasemigration.model.VpcSecurityGroupMembership]
}
